@@ -82,7 +82,7 @@ namespace msXpS
 	/*!
 	 * Describe how many times the whole gaussian/lorentzian curve should span
 	 * around the centroid mz ratio. 4 means that the peak will span
-	 : [ mzRatio - (2 * FWHM) --> mzRatio + (2 * FWHM) ]
+	 * : [ mz - (2 * FWHM) --> mz + (2 * FWHM) ]
 	 */
 	int FWHM_PEAK_SPAN_FACTOR = 4;
 
@@ -116,8 +116,10 @@ namespace msXpS
 	/**@}*/
 
 	//! Regular expression that tracks the m/z,i pairs in text files.
+	// One val (intensity) value can be like this: 8.19179e-05
 	QRegularExpression gXyFormatMassDataRegExp =
-		QRegularExpression("^(\\d*\\.?\\d+)([^\\d^\\.^-]+)(-?\\d*\\.?\\d*[e-]?\\d*)");
+		QRegularExpression("^(\\d*\\.?\\d*[e]?[-]?[+]?\\d*)([^\\d^\\.^-]+)(-?\\d*\\.?\\d*[e]?[-]?[+]?\\d*)");
+
 
 	//! Regular expression that tracks the end of line in text files.
 	QRegularExpression gEndOfLineRegExp = QRegularExpression("^\\s+$") ;
