@@ -47,10 +47,11 @@
 
 #include <pwiz/data/msdata/MSDataFile.hpp>
 #include <pwiz/data/msdata/DefaultReaderList.hpp>
+
+#if defined(WIN64) || defined(APPLE)
+#else // UNIX/GNU/LINUX
 #include <pwiz/utility/misc/BinaryData.hpp>
-
-using namespace pwiz::msdata;
-
+#endif
 
 namespace msXpSlibmass
 {
@@ -547,15 +548,20 @@ Trace::initialize(const QByteArray *keyByteArray,
     config.compression =
       pwiz::msdata::BinaryDataEncoder::Compression::Compression_Zlib;
 
-  BinaryDataEncoder decoder(config);
+  // Allocate the decoder
+  pwiz::msdata::BinaryDataEncoder decoder(config);
 
-  // Start by crunching the key data.
-
-	pwiz::util::BinaryData<double> keyStdVector;
+  // Crunching the key (mz) data.
 
   std::string keyString = keyByteArray->toStdString();
 
+#if defined(WIN64) || defined(APPLE)
+  std::vector<double> keyStdVector;
   decoder.decode(keyString, keyStdVector);
+#else // UNIX/GNU/LINUX
+  pwiz::util::BinaryData<double> keyStdVector;
+  decoder.decode(keyString, keyStdVector);
+#endif
 
   QVector<double> keyVector = QVector<double>::fromStdVector(keyStdVector);
 
@@ -565,13 +571,18 @@ Trace::initialize(const QByteArray *keyByteArray,
   // qDebug() << __FILE__ << __LINE__
   //<< "Done creating keyVector of items: " << keyVector.size();
 
-  // And now do the same for the i data.
 
-	pwiz::util::BinaryData<double> valStdVector;
+  // Crunching the val (i) data.
 
   std::string valString = valByteArray->toStdString();
 
+#if defined(WIN64) || defined(APPLE)
+  std::vector<double> valStdVector;
   decoder.decode(valString, valStdVector);
+#else // UNIX/GNU/LINUX
+  pwiz::util::BinaryData<double> valStdVector;
+  decoder.decode(valString, valStdVector);
+#endif
 
   QVector<double> valVector = QVector<double>::fromStdVector(valStdVector);
 
@@ -607,7 +618,7 @@ Trace::removeZeroValDataPoints()
 {
   // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
   //<< "Removing from this Trace all the DataPoint instances that have a value
-  //equal to 0.";
+  // equal to 0.";
 
   int removedCount = 0;
 
@@ -1922,6 +1933,32 @@ Trace::contains(double key) const
 }
 
 
+double
+Trace::valueAt(double key, double tolerance, bool &ok) const
+{
+  int specSize = size();
+
+  double minMz = key - (tolerance / 2);
+  double maxMz = key + (tolerance / 2);
+
+  for(int iter = 0; iter < specSize; ++iter)
+    {
+      double iterMz = at(iter)->key();
+
+      if(iterMz <= maxMz && iterMz >= minMz)
+        {
+          ok = true;
+
+          return at(iter)->val();
+        }
+    }
+
+  ok = false;
+
+  return 0;
+}
+
+
 //! Fills in a list of double values containing all the keys in \c this Trace.
 /*!
 
